@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2020	PgPool Global Development Group
+ * Copyright (c) 2003-2021	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -49,7 +49,8 @@ char	*application_names[] = {"main",
 								"watchdog_utility",
 								"pcp_main",
 								"pcp_child",
-								"health_check"
+								"health_check",
+								"logger"
 };
 
 char *
